@@ -2,12 +2,12 @@ package Hades::Realm::OO;
 use strict;
 use warnings;
 use base qw/Hades/;
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new {
 	my ( $cls, %args ) = ( shift(), scalar @_ == 1 ? %{ $_[0] } : @_ );
 	my $self      = $cls->SUPER::new(%args);
-	my %accessors = ( meta => {}, current_class => {}, is_role => {}, );
+	my %accessors = ( current_class => {}, is_role => {}, meta => {}, );
 	for my $accessor ( keys %accessors ) {
 		my $value
 		    = $self->$accessor(
@@ -282,10 +282,14 @@ sub build_accessor {
 
 	$mg->has($name);
 	$meta->{$name}->{$_} and $mg->$_(
-		  $self->can("build_accessor_${_}")
-		? $self->can("build_accessor_${_}")
-		    ->( $self, $name, $meta->{$name}->{$_} )
-		: $meta->{$name}->{$_}
+		$self->build_code(
+			$mg,
+			$name,
+			$self->can("build_accessor_${_}")
+			? $self->can("build_accessor_${_}")
+			    ->( $self, $name, $meta->{$name}->{$_} )
+			: $meta->{$name}->{$_}
+		)
 	) for ( @{ $self->build_has_keywords } );
 	$mg->isa(
 		  $self->can("build_accessor_isa")
@@ -319,7 +323,8 @@ sub build_modify {
 	}
 
 	$meta->{$name}->{$_}
-	    && $mg->$_($name)->code( delete $meta->{$name}->{$_} )
+	    && $mg->$_($name)
+	    ->code( $self->build_code( $mg, $name, delete $meta->{$name}->{$_} ) )
 	    ->test( $self->build_tests( $name, $meta->{$name} ) )
 	    for qw/before around after/;
 	$meta->{$name}->{$_}
@@ -459,9 +464,9 @@ sub build_has {
 	return qq|{
 			my ( \$self, \$value ) = \@_; $private
 			if ( defined \$value ) { $type
-				\$self->{$name} = \$value; $trigger
+				$self->{$name} = \$value; $trigger
 			}
-			return \$self->{$name};
+			return $self->{$name};
 		}|;
 
 }
